import React, { useState, useEffect } from 'react';
import { Table, Button, Modal, Form, Input, Space, App as AntdApp } from 'antd';
import { useGet, usePost, usePut, useDelete } from '../../hooks/useApi';

interface Location {
  id: number;
  name: string;
  description?: string;
}

const LocationManagement: React.FC = () => {
  const [isModalVisible, setIsModalVisible] = useState(false);
  const [editingLocation, setEditingLocation] = useState<Location | null>(null);
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  const { message } = AntdApp.useApp();

  // API хуки
  const { data: locations, execute: fetchLocations } = useGet<Location[]>('/admin/locations');
  const { execute: createLocation } = usePost('/admin/locations');
  const { execute: updateLocation } = usePut(`/admin/locations/${editingLocation?.id}`);
  const { execute: deleteLocation } = useDelete(`/admin/locations`);

  useEffect(() => {
    fetchLocations();
  }, []);

  const handleSubmit = async (values: any) => {
    setLoading(true);
    try {
      if (editingLocation) {
        await updateLocation(values);
        message.success('Локация обновлена');
      } else {
        await createLocation(values);
        message.success('Локация создана');
      }
      setIsModalVisible(false);
      form.resetFields();
      setEditingLocation(null);
      fetchLocations();
    } catch {
      message.error('Ошибка при сохранении локации');
    } finally {
      setLoading(false);
    }
  };

  const handleEdit = (location: Location) => {
    setEditingLocation(location);
    form.setFieldsValue({
      name: location.name,
      description: location.description
    });
    setIsModalVisible(true);
  };

  const handleDelete = async (locationId: number) => {
    try {
      await deleteLocation(locationId);
      message.success('Локация удалена');
      fetchLocations();
    } catch {
      message.error('Ошибка при удалении локации');
    }
  };

  const columns = [
    {
      title: 'Название',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: 'Описание',
      dataIndex: 'description',
      key: 'description',
    },
    {
      title: 'Действия',
      key: 'actions',
      render: (_: any, record: Location) => (
        <Space>
          <Button type="link" onClick={() => handleEdit(record)}>
            Редактировать
          </Button>
          <Button type="link" danger onClick={() => handleDelete(record.id)}>
            Удалить
          </Button>
        </Space>
      ),
    },
  ];

  return (
    <div>
      <Button
        type="primary"
        onClick={() => {
          setEditingLocation(null);
          form.resetFields();
          setIsModalVisible(true);
        }}
        style={{ marginBottom: 16 }}
      >
        Создать локацию
      </Button>

      <Table
        columns={columns}
        dataSource={locations || []}
        rowKey="id"
        loading={!locations}
      />

      <Modal
        title={editingLocation ? 'Редактировать локацию' : 'Создать локацию'}
        open={isModalVisible}
        onOk={() => form.submit()}
        onCancel={() => {
          setIsModalVisible(false);
          setEditingLocation(null);
          form.resetFields();
        }}
        confirmLoading={loading}
      >
        <Form
          form={form}
          onFinish={handleSubmit}
          layout="vertical"
        >
          <Form.Item
            name="name"
            label="Название"
            rules={[{ required: true, message: 'Введите название локации' }]}
          >
            <Input />
          </Form.Item>

          <Form.Item
            name="description"
            label="Описание"
          >
            <Input.TextArea />
          </Form.Item>
        </Form>
      </Modal>
    </div>
  );
};

export default LocationManagement; 